Learn R Programming

devRate (version 0.1.1)

bayoh_03: Bayoh and Lindsay equation of development rate as a function of temperature.

Description

Bayoh, M.N., Lindsay, S.W. (2003) Effect of temperature on the development of the aquatic stages of Anopheles gambiae sensu stricto (Diptera: Culicidae). Bulletin of entomological research 93(5): 375-81.

Usage

bayoh_03

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ aa + bb * T + cc * exp(T) + dd * exp(-T)

where rT is the development rate, T the temperature, and aa, bb, cc, and dd empirical constant parameters.