Learn R Programming

devRate (version 0.1.1)

beta_95: Beta equation of development rate as a function of temperature.

Description

Yin, X., Kropff, M.J., McLaren, G., and Visperas, R.M. (1995) A nonlinear model for crop development as a function of temperature. Agricultural and Forest Meteorology 77(1): 1-16.

Usage

beta_95

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ exp(mu) * (T - Tb)^aa * (Tc - T)^bb

where rT is the development rate, T the temperature, mu, aa, and bb the model parameters, Tb the base temperature, and Tc the ceiling temperature.