Learn R Programming

devRate (version 0.1.1)

briere2_99: Briere et al equation 2 of development rate as a function of temperature.

Description

Briere, J.F., Pracros, P., le Roux, A.Y. and Pierre, S. (1999) A novel rate model of temperature-dependent development for arthropods. Environmental Entomology, 28, 22-29.

Usage

briere2_99

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ aa * T * (T - Tmin) * (Tmax - T)^(1 / bb)

where rT is the development rate, T the temperature, Tmin the low temperature developmental threshold, Tmax the lethal temperature, and aa and bb empirical constants.