Learn R Programming

devRate (version 0.1.1)

campbell_74: Campbell et al. equation of development rate as a function of temperature.

Description

Campbell, A., Frazer, B. D., Gilbert, N. G. A. P., Gutierrez, A. P., & Mackauer, M. (1974). Temperature requirements of some aphids and their parasites. Journal of applied ecology, 431-438.

Usage

campbell_74

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ aa + bb * T

where rT is the development rate, T the temperature, bb the slope, and aa the point at which the line crosses the rT axis when T = 0.