Learn R Programming

devRate (version 0.1.1)

compDifDays: Compute the inverse of number of days between dates

Description

compDifDays computes the inverse of the difference between dates form a vector made of dates.

Usage

compDifDays(vecDates, dateFormat = "%d/%m/%y")

Arguments

vecDates
A vector with dates.
dateFormat
The format of dates (see strptime).

Value

A vector with the inverse of the difference between dates.

Examples

Run this code
compDifDays(vecDates = c("28/12/15", "12/01/16", "25/01/16", "28/02/16", "15/03/16"))
compDifDays(vecDates = c("28/12/15", "12/01/14", "25/01/16", "28/02/16", "15/03/16"))
compDifDays(vecDates = c("28/12/15", "12/01/16", "25/01/16", "", ""))

Run the code above in your browser using DataLab