Learn R Programming

devRate (version 0.1.1)

damos_08: Simplified beta type equation of development rate as a function of temperature.

Description

Damos, P.T., and Savopoulou-Soultani, M. (2008). Temperature-dependent bionomics and modeling of Anarsia lineatella (Lepidoptera: Gelechiidae) in the laboratory. Journal of economic entomology, 101(5), 1557-1567.

Usage

damos_08

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ aa * (bb - T / 10) * (T / 10)^cc rT ~ aa * (T - Tmin)^2 * (Tmax - T)

where rT is the development rate, T the temperature, and aa, bb, and cc empirical constant parameters.