Learn R Programming

devRate (version 0.1.1)

damos_11: Inverse second-order polynomial equation of development rate as a function of temperature.

Description

Damos, P., and Savopoulou-Soultani, M. (2011) Temperature-driven models for insect development and vital thermal requirements. Psyche: A Journal of Entomology, 2012.

Usage

damos_11

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ aa / (1 + bb * T + cc * T^2)

where rT is the development rate, T the temperature, and aa, bb, and cc empirical constant parameters.