Learn R Programming

devRate (version 0.1.1)

devRateMap: Predict development rate from a a map of temperatures

Description

Create a map from a temperature matrix and the development rate curve

Usage

devRateMap(nlsDR, tempMap)

Arguments

nlsDR
The result returned by the devRateModel function.
tempMap
A matrix containing temperatures in degrees.

Value

A matrix with development rates predicted from the model.

Details

The devRateMap function is designed for a single ecthoterm life stage, but the resulted matrix of development rate can be performed for each life stage in order to obtain the whole organism development. Input temperatures should preferably cover the orgnaism development period rather than the whole year.

Examples

Run this code
myT <- 5:15
myDev <- -0.05 + rnorm(n = length(myT), mean = myT, sd = 1) * 0.01
myNLS <- devRateModel(eq = campbell_74, temp = myT, devRate = myDev,
  startValues = list(aa = 0, bb = 0))
myMap <- devRateMap(nlsDR =  myNLS, tempMap = matrix(rnorm(100, mean = 12, sd = 2), ncol=10))

Run the code above in your browser using DataLab