Learn R Programming

devRate (version 0.1.10)

devRatePlot: Plot the empirical points and the regression

Description

Plot the empirical points and the regression

Usage

devRatePlot(eq, nlsDR, temp, devRate, rangeT = 10, optText = TRUE,
  spe = TRUE, ...)

Arguments

eq

The name of the equation.

nlsDR

The result returned by the devRateModel function.

temp

The temperature.

devRate

The development rate (days)^-1

rangeT

The range of temperatures over which the regression is plotted. This argument may be overwritten depending on the equation.

optText

A logical indicating whether the name of the equation should be written in the topright corner of the plot.

spe

A logical indicating if special plotting rules from literature should apply.

...

Additional arguments for the plot.

Value

Nothing.

Examples

Run this code
# NOT RUN {
myT <- 5:15
myDev <- -0.05 + rnorm(n = length(myT), mean = myT, sd = 1) * 0.01
myNLS <- devRateModel(eq = campbell_74, temp = myT, devRate = myDev,
  startValues = list(aa = 0, bb = 0))
devRatePlot(eq = campbell_74, nlsDR = myNLS, temp = myT, devRate = myDev,
  spe = TRUE, pch = 16, lwd = 2, ylim = c(0, 0.10))
# }

Run the code above in your browser using DataLab