Learn R Programming

devRate (version 0.1.1)

harcourtYee_82: Harcourt and Yee equation of development rate as a function of temperature.

Description

Harcourt, D. and Yee, J. (1982) Polynomial algorithm for predicting the duration of insect life stages. Environmental Entomology, 11, 581-584.

Usage

harcourtYee_82

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ a0 + a1 * T + a2 * T^2 + a3 * T^3