Learn R Programming

devRate (version 0.1.1)

hilbertLogan_83: Holling type III equation of development rate as a function of temperature.

Description

Hilbert, DW, y JA Logan (1983) Empirical model of nymphal development for the migratory grasshopper, Melanoplus sanguinipes (Orthoptera: Acrididae). Environmental Entomology 12(1): 1-5.

Usage

hilbertLogan_83

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ phi * (((T-Tb)^2 / ((T-Tb)^2 + aa^2)) - exp(-(Tmax - (T-Tb))/deltaT))

where rT is the development rate, T the temperature, Tb the minimum temperature for development, deltaT the width of high temperature boundary area, Tmax the maximum temperature, and aa a constant.