Learn R Programming

devRate (version 0.1.1)

logan6_76: Logan et al. equation 6 of development rate as a function of temperature.

Description

Logan, J. A., Wollkind, D. J., Hoyt, S. C., and Tanigoshi, L. K. (1976). An analytic model for description of temperature dependent rate phenomena in arthropods. Environmental Entomology, 5(6), 1133-1140.

Usage

logan6_76

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ phi * (exp(bb * T) - exp(bb * Tmax - (Tmax - T)/deltaT))

where rT is the development rate, T the temperature, Tmax the maximum temperature, deltaT the width of the high temperature boundary layer, phi the developmental rate at some base temperature above developmental threshold, and bb a constant.