Learn R Programming

devRate (version 0.1.1)

regniere_12: Regniere equation of development rate as a function of temperature.

Description

Regniere, J., Powell, J., Bentz, B., and Nealis, V. (2012) Effects of temperature on development, survival and reproduction of insects: experimental design, data analysis and modeling. Journal of Insect Physiology 58(5): 634-47.

Usage

regniere_12

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ phi * (exp(bb * (T - Tb)) - ((Tm - T)/(Tm - Tb)) * exp(-bb * (T - Tb) / deltab) - ((T - Tb)/(Tm - Tb)) * exp(bb * (Tm - Tb) - (Tm - T)/deltam))

where rT is the development rate, T the temperature, and the others thermodynamic parameters (see source).