Learn R Programming

devRate (version 0.1.1)

sharpeDeMichele_77: Sharpe and DeMichele equation of development rate as a function of temperature.

Description

Sharpe, P.J. & DeMichele, D.W. (1977) Reaction kinetics of poikilotherm development. Journal of Theoretical Biology, 64, 649-670.

Usage

sharpeDeMichele_77

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ ((T + 273.16) * exp((aa - bb/(T + 273.16))/1.987)) / (1 + exp((cc - dd/(T + 273.16))/1.987) + exp((ff - gg/(T + 273.16))/1.987))

where rT is the development rate, T the temperature, and aa, bb, cc, dd, ff, and gg thermodynamic parameters