Learn R Programming

devRate (version 0.1.1)

shi_11: Shi equation of development rate as a function of temperature.

Description

Shi, P., Ge, F., Sun, Y., and Chen, C. (2011) A simple model for describing the effect of temperature on insect developmental rate. Journal of Asia-Pacific Entomology 14(1): 15-20.

Usage

shi_11

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ cc * (1 - exp(-k1 * (T - T1))) * (1 - exp(k2 * (T - T2)))

where rT is the development rate, T the temperature, T1 and T2 the conceptual lower and upper developmental thresholds at which development rates equal zero, and cc k1, and k2 constants.