Learn R Programming

devRate (version 0.1.1)

stinner_74: Stinner et al equation of development rate as a function of temperature.

Description

Stinner, R., Gutierrez, A. & Butler, G. (1974) An algorithm for temperature-dependent growth rate simulation. The Canadian Entomologist, 106, 519-524.

Usage

stinner_74

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: c(rT ~ C / (1 + exp(k1 + k2 * T)), rT ~ C / (1 + exp(k1 + k2 * (2 * Topt - T))))

where rT is the development rate, T the temperature, Topt the optimum temperature, k1 and k2 constants. "[...] the relationship [is] inverted when the temperature is above an optimum [...] T = 2 * Topt - T for T >= Topt." Stinner et al. 1974.