Learn R Programming

devRate (version 0.1.1)

wang_82: Wang et al. equation of development rate as a function of temperature.

Description

Wang, R., Lan, Z. and Ding, Y. (1982) Studies on mathematical models of the relationship between insect development and temperature. Acta Ecol. Sin, 2, 47-57.

Usage

wang_82

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ (K / (1 + exp(-r*(T - T0)))) * (1 - exp(-(T - TL)/aa)) * (1-exp(-(TH - T)/aa))

where rT is the development rate, and T the temperature.