Learn R Programming

devRate (version 0.1.1)

wangengel_98: Wang and Engel equation of development rate as a function of temperature.

Description

Wang, E., and Engel, T. (1998) Simulation of phenological development of wheat crops. Agricultural systems 58(1): 1-24.

Usage

wangengel_98

Arguments

Format

A list of eight elements describing the equation.

Details

Equation: rT ~ (2 * (T - Tmin)^aa * (Topt - Tmin)^aa - (T - Tmin)^(2 * aa)) / ((Topt - Tmin)^(2 * aa))

where rT is the development rate, T the temperature, Tmin the minimum temperature, Topt the optimum temperature, and aa a constant.